pub struct TrackerConfig<'a> {
pub enable: bool,
pub level: Level,
pub filter_regex: &'a str,
pub file: Option<&'a str>,
}Expand description
Configuration options for an individual tracker.
Fields
enable: boolEnable this tracker.
level: LevelSet the level at which this tracker should be enabled.
filter_regex: &'a strA regular expression to match which entities should have this level applied.
file: Option<&'a str>If required, the name of the file to which the tracker will write.