pub struct EntityLane {
pub entity: Rc<Entity>,
pub id: Id,
pub name: String,
/* private fields */
}Expand description
A child trace lane used to represent named activity intervals.
Fields
entity: Rc<Entity>Parent entity that owns this lane.
id: IdUnique simulation identifier used for trace events.
name: StringName of this lane.
Implementations
Sourceimpl EntityLane
impl EntityLane
Sourcepub fn begin_in_group(&mut self, name: &str, group: &EntityGroup)
pub fn begin_in_group(&mut self, name: &str, group: &EntityGroup)
Begin the named activity as part of a group.