create_id

Macro create_id 

macro_rules! create_id {
    ($entity:expr) => { ... };
}
Create a unique ID for tracking.

The user must specify an entity with a Tracker to create the ID.

Note: this macro should be used when the object being assigned the Id will have its creation tracked with the track_create_object macro.