log_base

Macro log_base 

macro_rules! log_base {
    ($entity:expr ; $lvl:expr, $($arg:tt)+) => { ... };
}
Base macro for log messages of all level.

This wrapper calls both the log::log macro and also the Trace message function which will emit message tracking events to the Cap’n Proto binary stream.