TestTracker

Struct TestTracker 

pub struct TestTracker { /* private fields */ }
A tracker that keeps track events.

Implementations

Source

impl TestTracker

pub fn new(initial_id: u64, level: Level) -> Self

Create a new Tracker for the tests.

This keeps the track events in memory for checking later.

pub fn events(&self) -> Vec<String>

Return a snapshot of the events recorded so far.