pub fn populate_aka(
aka: Option<&Aka>,
new_aka: Option<&mut Aka>,
entity: &Rc<Entity>,
renames: &[(&str, &str)],
)Expand description
Build up a new set of alternative names with a new set of renames.
Each tuple maps a name visible on entity to the child-local name that
should inherit the alternative names. For example, a composite can map a
public rx_a port to an internal limiter’s rx port so traces and monitor
configuration can refer to either level of the model.