pub struct TrackerArgs {Show 13 fields
pub stdout: bool,
pub stdout_level: Level,
pub stdout_filter_regex: String,
pub binary: bool,
pub binary_level: Level,
pub binary_filter_regex: String,
pub binary_file: String,
pub perfetto: bool,
pub perfetto_level: Level,
pub perfetto_filter_regex: String,
pub perfetto_file: String,
pub monitor_window_ticks: Option<u64>,
pub monitor_filter_regex: String,
}Expand description
Standard command-line arguments for tracker configuration.
Fields
stdout: boolEnable logging to the console.
stdout_level: LevelLevel of log message to display.
stdout_filter_regex: StringSet a regular expression for which entities should have logging level
set to --stdout-level. Others will have level set to Error.
binary: boolEnable logging to binary file used by gwr-spotter.
binary_level: LevelLevel of binary trace events to record.
binary_filter_regex: StringSet a regular expression for which entities should have binary output
level set to --binary-level. Others will have level set to Error.
binary_file: StringThe filename binary trace output is written to.
perfetto: boolEnable logging to Perfetto file used by gwr-spotter.
perfetto_level: LevelLevel of Perfetto trace events to record.
perfetto_filter_regex: StringSet a regular expression for which entities should have Perfetto output
level set to --perfetto-level. Others will have level set to Error.
perfetto_file: StringThe filename Perfetto trace output is written to.
monitor_window_ticks: Option<u64>Enable monitoring at the specified number of clock ticks.
monitor_filter_regex: StringSet a regular expression for which ports should have monitors enabled.
Implementations
Sourceimpl TrackerArgs
impl TrackerArgs
Sourcepub fn tracking_requested(&self) -> bool
pub fn tracking_requested(&self) -> bool
Return whether any tracker output has been explicitly requested.
Sourcepub fn level_enabled(&self, level: Level) -> bool
pub fn level_enabled(&self, level: Level) -> bool
Return whether any configured tracker will emit messages at level.
Sourcepub fn ensure_visiblity(
&mut self,
feature: bool,
feature_name: &str,
level: Level,
)
pub fn ensure_visiblity( &mut self, feature: bool, feature_name: &str, level: Level, )
Ensure that if the specified feature is enabled then a tracker will be showing messages of that level
Sourcepub fn trackers_config(&self) -> TrackersConfig<'_>
pub fn trackers_config(&self) -> TrackersConfig<'_>
Convert these command-line arguments into a TrackersConfig.