macro_rules! destroy_id {
($entity:expr ; $id:expr) => { ... };
}Expand description
Destroy an ID
Destroying an ID indicates to the logging system that this ID is finished with and should therefore not be used any more. This is not enforced at runtime, and therefore will not cause any errors to be reported if it is used.